package com.qmth.distributed.print.business.service.impl;

import com.qmth.distributed.print.business.service.ActivitiService;
import org.activiti.engine.RepositoryService;
import org.activiti.engine.RuntimeService;
import org.activiti.engine.TaskService;
import org.activiti.engine.repository.DeploymentBuilder;
import org.activiti.engine.runtime.ProcessInstance;
import org.activiti.engine.task.Task;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Description: activiti service impl
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/7/12
 */
@Service
public class ActivitiServiceImpl implements ActivitiService {
    private final static Logger log = LoggerFactory.getLogger(ActivitiServiceImpl.class);

    @Resource
    private RuntimeService runtimeService;

    @Resource
    private TaskService taskService;

    @Resource
    private RepositoryService repositoryService;

    /**
     * 注册流程
     *
     * @param processFileName
     */
    @Override
    public void createDeployment(String processFileName) {
        DeploymentBuilder builder = repositoryService.createDeployment();
        builder.addClasspathResource(processFileName);
        builder.deploy();
    }

    /**
     * 查询待办
     */
    @Override
    public void getTaskList() {
        //获取待办的一些信息，这里可以传入需要查询的用户，
        //我这里查询的所有待办
        List<Task> tasks = taskService.createTaskQuery().list();
        for (Task t : tasks) {
            log.info("createTime:{},id:{},name:{},processInstanceId:{},taskDefinitionKey:{},parentTaskId:{}", t.getCreateTime(), t.getId(), t.getName(), t.getProcessInstanceId(), t.getTaskDefinitionKey(), t.getParentTaskId());
        }
    }


    /**
     * 根据流程key开启一个流程
     *
     * @param processKey
     */
    @Override
    public void startActivityDemo(String processKey) {
        ProcessInstance processInstance = runtimeService.startProcessInstanceByKey(processKey);
        log.info("流程id:{}", processInstance.getId());
    }

    /**
     * 根据任务id提交任务
     *
     * @param taskId
     */
    @Override
    public void complete(String taskId) {
        taskService.complete(taskId);
    }

    /**
     * 根据流程id直接结束流程
     *
     * @param flowId
     */
    @Override
    public void deleteProcessInstance(String flowId) {
        runtimeService.deleteProcessInstance(flowId, "结束");
    }
}
